[Lldb-commits] [lldb] r241289 - Fix typos

Bruce Mitchener bruce.mitchener at gmail.com
Thu Jul 2 11:48:41 PDT 2015


Author: brucem
Date: Thu Jul  2 13:48:40 2015
New Revision: 241289

URL: http://llvm.org/viewvc/llvm-project?rev=241289&view=rev
Log:
Fix typos

Summary: Fixes more typos.

Reviewers: clayborg

Subscribers: lldb-commits-list

Differential Revision: http://reviews.llvm.org/D10898

Modified:
    lldb/trunk/examples/synthetic/unordered_multi.py
    lldb/trunk/source/Plugins/Platform/Linux/PlatformLinux.cpp
    lldb/trunk/source/Plugins/Platform/MacOSX/PlatformDarwinKernel.cpp
    lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp
    lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp
    lldb/trunk/test/lang/c/stepping/TestStepAndBreakpoints.py
    lldb/trunk/test/lang/c/stepping/main.c

Modified: lldb/trunk/examples/synthetic/unordered_multi.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/examples/synthetic/unordered_multi.py?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================
--- lldb/trunk/examples/synthetic/unordered_multi.py (original)
+++ lldb/trunk/examples/synthetic/unordered_multi.py Thu Jul  2 13:48:40 2015
@@ -15,7 +15,7 @@ class libcxx_hash_table_SynthProvider:
 		self.next_element = None
 		self.bucket_count = None
 		try:
-			# unordered_map is made up a a hash_map, which has 4 pieces in it:
+			# unordered_map is made up of a hash_map, which has 4 pieces in it:
 			#   bucket list :
 			#      array of buckets
 			#   p1 (pair):
@@ -27,7 +27,7 @@ class libcxx_hash_table_SynthProvider:
 			#      first - max_load_factor
 			#      second - equality operator function
 			#
-			# For display, we actually dont need to go inside the buckets, since 'p1' has a way to iterate over all
+			# For display, we actually don't need to go inside the buckets, since 'p1' has a way to iterate over all
 			# the elements directly.
 			#
 			# We will calculate other values about the map because they will be useful for the summary.
@@ -46,7 +46,7 @@ class libcxx_hash_table_SynthProvider:
 			logger >> "Num elements = %r" % self.num_elements
 
 			# save the pointers as we get them
-			#   -- dont access this first element if num_element==0!
+			#   -- don't access this first element if num_element==0!
 			self.elements_cache = []
 			if self.num_elements:
 				self.next_element = self.begin_ptr

Modified: lldb/trunk/source/Plugins/Platform/Linux/PlatformLinux.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Platform/Linux/PlatformLinux.cpp?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Platform/Linux/PlatformLinux.cpp (original)
+++ lldb/trunk/source/Plugins/Platform/Linux/PlatformLinux.cpp Thu Jul  2 13:48:40 2015
@@ -40,7 +40,7 @@
 #include "../../Process/Linux/NativeProcessLinux.h"
 #endif
 
-// Define these constants from Linux mman.h for use when targetting
+// Define these constants from Linux mman.h for use when targeting
 // remote linux systems even when host has different values.
 #define MAP_PRIVATE 2
 #define MAP_ANON 0x20

Modified: lldb/trunk/source/Plugins/Platform/MacOSX/PlatformDarwinKernel.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Platform/MacOSX/PlatformDarwinKernel.cpp?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Platform/MacOSX/PlatformDarwinKernel.cpp (original)
+++ lldb/trunk/source/Plugins/Platform/MacOSX/PlatformDarwinKernel.cpp Thu Jul  2 13:48:40 2015
@@ -80,7 +80,7 @@ PlatformSP
 PlatformDarwinKernel::CreateInstance (bool force, const ArchSpec *arch)
 {
     // This is a special plugin that we don't want to activate just based on an ArchSpec for normal
-    // userlnad debugging.  It is only useful in kernel debug sessions and the DynamicLoaderDarwinPlugin
+    // userland debugging.  It is only useful in kernel debug sessions and the DynamicLoaderDarwinPlugin
     // (or a user doing 'platform select') will force the creation of this Platform plugin.
     if (force == false)
         return PlatformSP();

Modified: lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp (original)
+++ lldb/trunk/source/Plugins/Process/MacOSX-Kernel/ProcessKDP.cpp Thu Jul  2 13:48:40 2015
@@ -582,7 +582,7 @@ ProcessKDP::UpdateThreadList (ThreadList
         log->Printf ("ProcessKDP::%s (pid = %" PRIu64 ")", __FUNCTION__, GetID());
     
     // Even though there is a CPU mask, it doesn't mean we can see each CPU
-    // indivudually, there is really only one. Lets call this thread 1.
+    // individually, there is really only one. Lets call this thread 1.
     ThreadSP thread_sp (old_thread_list.FindThreadByProtocolID(g_kernel_tid, false));
     if (!thread_sp)
         thread_sp = GetKernelThread ();

Modified: lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp (original)
+++ lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp Thu Jul  2 13:48:40 2015
@@ -1113,7 +1113,7 @@ GDBRemoteCommunicationClient::SendContin
                             {
                                 continue_after_async = false;
 
-                                // We didn't get a a SIGINT or SIGSTOP, so try for a
+                                // We didn't get a SIGINT or SIGSTOP, so try for a
                                 // very brief time (1 ms) to get another stop reply
                                 // packet to make sure it doesn't get in the way
                                 StringExtractorGDBRemote extra_stop_reply_packet;

Modified: lldb/trunk/test/lang/c/stepping/TestStepAndBreakpoints.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/lang/c/stepping/TestStepAndBreakpoints.py?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================
--- lldb/trunk/test/lang/c/stepping/main.c (original)
+++ lldb/trunk/test/lang/c/stepping/main.c Thu Jul  2 13:48:40 2015
@@ -42,7 +42,7 @@ int c(int val)
 
 int complex (int first, int second, int third)
 {
-    return first + second + third;  // Step in targetting complex should stop here
+    return first + second + third;  // Step in targeting complex should stop here
 }
 
 int main (int argc, char const *argv[])
@@ -56,11 +56,11 @@ int main (int argc, char const *argv[])
     int A3 = a(3); // frame select 1, thread step-out while stopped at "c(3)"
     printf("a(3) returns %d\n", A3);
     
-    int A4 = complex (a(1), b(2), c(3)); // Stop here to try step in targetting b.
+    int A4 = complex (a(1), b(2), c(3)); // Stop here to try step in targeting b.
 
-    int A5 = complex (a(2), b(3), c(4)); // Stop here to try step in targetting complex.
+    int A5 = complex (a(2), b(3), c(4)); // Stop here to try step in targeting complex.
 
-    int A6 = complex (a(4), b(5), c(6)); // Stop here to step targetting b and hitting breakpoint.
+    int A6 = complex (a(4), b(5), c(6)); // Stop here to step targeting b and hitting breakpoint.
 
     int A7 = complex (a(5), b(6), c(7)); // Stop here to make sure bogus target steps over.
 





More information about the lldb-commits mailing list
--- lldb/trunk/test/lang/c/stepping/TestStepAndBreakpoints.py (original)
+++ lldb/trunk/test/lang/c/stepping/TestStepAndBreakpoints.py Thu Jul  2 13:48:40 2015
@@ -185,17 +185,17 @@ class TestCStepping(TestBase):
         self.assertTrue (thread.GetFrameAtIndex(0).GetLineEntry().GetLine() == current_line)
         self.assertTrue (thread.GetFrameAtIndex(0).GetLineEntry().GetFileSpec() == current_file)
 
         # Now we are going to test step in targetting a function:
 
         break_in_b.SetEnabled (False)
 
-        break_before_complex_1 = target.BreakpointCreateBySourceRegex ('// Stop here to try step in targetting b.', self.main_source_spec)
+        break_before_complex_1 = target.BreakpointCreateBySourceRegex ('// Stop here to try step in targeting b.', self.main_source_spec)
         self.assertTrue(break_before_complex_1, VALID_BREAKPOINT)
 
-        break_before_complex_2 = target.BreakpointCreateBySourceRegex ('// Stop here to try step in targetting complex.', self.main_source_spec)
+        break_before_complex_2 = target.BreakpointCreateBySourceRegex ('// Stop here to try step in targeting complex.', self.main_source_spec)
         self.assertTrue(break_before_complex_2, VALID_BREAKPOINT)
 
-        break_before_complex_3 = target.BreakpointCreateBySourceRegex ('// Stop here to step targetting b and hitting breakpoint.', self.main_source_spec)
+        break_before_complex_3 = target.BreakpointCreateBySourceRegex ('// Stop here to step targeting b and hitting breakpoint.', self.main_source_spec)
         self.assertTrue(break_before_complex_3, VALID_BREAKPOINT)
 
         break_before_complex_4 = target.BreakpointCreateBySourceRegex ('// Stop here to make sure bogus target steps over.', self.main_source_spec)
@@ -218,7 +218,7 @@ class TestCStepping(TestBase):
         thread.StepInto ("complex")
         self.assertTrue (thread.GetFrameAtIndex(0).GetFunctionName() == "complex")
         
         # Now continue out and stop at the next call to complex.  This time enable breakpoints in a and c and then step targetting b:
         threads = lldbutil.continue_to_breakpoint (process, break_before_complex_3)
         self.assertTrue (len(threads) == 1)
         thread = threads[0]
@@ -241,7 +241,7 @@ class TestCStepping(TestBase):
         process.Continue()
         self.assertTrue (thread.GetFrameAtIndex(0).GetFunctionName() == "b")
         
         # Now continue out and stop at the next call to complex.  This time enable breakpoints in a and c and then step targetting b:
         threads = lldbutil.continue_to_breakpoint (process, break_before_complex_4)
         self.assertTrue (len(threads) == 1)
         thread = threads[0]
@@ -185,17 +185,17 @@ class TestCStepping(TestBase):
         self.assertTrue (thread.GetFrameAtIndex(0).GetLineEntry().GetFileSpec() == current_file)
 
-        # Now we are going to test step in targetting a function:
+        # Now we are going to test step in targeting a function:
 
         break_in_b.SetEnabled (False)
@@ -218,7 +218,7 @@ class TestCStepping(TestBase):
         self.assertTrue (thread.GetFrameAtIndex(0).GetFunctionName() == "complex")
         
-        # Now continue out and stop at the next call to complex.  This time enable breakpoints in a and c and then step targetting b:
+        # Now continue out and stop at the next call to complex.  This time enable breakpoints in a and c and then step targeting b:
         threads = lldbutil.continue_to_breakpoint (process, break_before_complex_3)
         self.assertTrue (len(threads) == 1)
@@ -241,7 +241,7 @@ class TestCStepping(TestBase):
         self.assertTrue (thread.GetFrameAtIndex(0).GetFunctionName() == "b")
         
-        # Now continue out and stop at the next call to complex.  This time enable breakpoints in a and c and then step targetting b:
+        # Now continue out and stop at the next call to complex.  This time enable breakpoints in a and c and then step targeting b:
         threads = lldbutil.continue_to_breakpoint (process, break_before_complex_4)
         self.assertTrue (len(threads) == 1)

Modified: lldb/trunk/test/lang/c/stepping/main.c
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/lang/c/stepping/main.c?rev=241289&r1=241288&r2=241289&view=diff
==============================================================================